/*
 * Copyright 2022 Logan Fick
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at: https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */

package dev.logal.crabstero;

import java.util.concurrent.ThreadFactory;

/**
 * Creates threads with custom branded names for visibility in tools such as htop.
 */
public final class CrabsteroThreadFactory implements ThreadFactory {
    private int threadNumber = 1;

    /**
     * Creates a new thread with an automatically set name.
     *
     * @param runnable The runnable to create the thread with.
     * @return A new thread with the name automatically set.
     */
    @Override
    public Thread newThread(final Runnable runnable) {
        final Thread thread = new Thread(runnable);

        thread.setName("Crabstero Worker Thread - " + threadNumber++);

        return thread;
    }
}